@@ -9,12 +9,14 @@ See the LICENSE and README files for more information
 Common definitions for emailfilter scripts.
 """
 
+import os
+
 from plib.classes import SendReceiveMixin
 
 EMAILFILTER_NAME = "emailfilter"
 EMAILFILTER_BUFSIZE = 65536
 EMAILFILTER_HOSTNAME = "localhost"
-EMAILFILTER_PORT = 5590 # Pick an arbitrary, unlikely to be used port
+EMAILFILTER_PORT = 5590 + os.getuid()
 
 EMAILFILTER_ADDR = (EMAILFILTER_HOSTNAME, EMAILFILTER_PORT)
 
